@@ -1423,7 +1423,7 @@ void boxbutton(int x, int y)
 
 void trackbox(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
-   XPoint 	newpos, upos;
+   XPoint 	newpos;
    polyptr      newbox;
    pointlist	pointptr;
 
