@@ -463,7 +463,7 @@ void setparammarks(genericptr thiselem)
 /* editing elements.					*/
 /*------------------------------------------------------*/
 
-int exprsub(genericptr thiselem)
+void exprsub(genericptr thiselem)
 {
    genericptr *pgen;
    eparamptr epp;
@@ -537,7 +537,7 @@ int exprsub(genericptr thiselem)
 
 /*------------------------------------------------------*/
 /* Make numerical parameter substitutions into an	*/
-/* element.
+/* element.						*/
 /*------------------------------------------------------*/
 
 int epsubstitute(genericptr thiselem, objectptr thisobj, objinstptr pinst,
