@@ -66,6 +66,7 @@ extern void FillPolygon(Display *, Window, GC, XPoint *, int, int, int);
 /* from elements.c: */
 
 /* element constructor functions */
+extern int getsubpartindex(pathptr);
 extern labelptr new_label(objinstptr, stringpart *, int, int, int);
 extern labelptr new_simple_label(objinstptr, char *, int, int, int);
 extern labelptr new_temporary_label(objectptr, char *, int, int);
@@ -404,7 +405,7 @@ extern void InvTransformPoints(XPoint *, XPoint *, short, XPoint, float,
 extern void manhattanize(XPoint *, polyptr, short, Boolean);
 extern void bboxcalc(short, short *, short *);
 extern void calcextents(genericptr *, short *, short *, short *, short *);
-extern void objinstbbox(objinstptr, XPoint *, Boolean);
+extern void objinstbbox(objinstptr, XPoint *, int);
 extern void labelbbox(labelptr, XPoint *, objinstptr);
 extern void graphicbbox(graphicptr, XPoint *);
 extern void calcinstbbox(genericptr *, short *, short *, short *, short *);
@@ -642,6 +643,7 @@ extern Tcl_Obj *tcltoplevel(objinstptr);
 void ratsnest(objectptr);
 #endif
 
+extern void ReferencePosition(objinstptr, XPoint *, XPoint *);
 extern int NameToPinLocation(objinstptr, char *, int *, int *);
 extern Boolean RemoveFromNetlist(objectptr, genericptr);
 extern labelptr NetToLabel(int, objectptr);
@@ -759,7 +761,7 @@ extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
 extern int opsubstitute(objectptr, objinstptr);
-extern int exprsub(genericptr);
+extern void exprsub(genericptr);
 extern int epsubstitute(genericptr, objectptr, objinstptr, Boolean *);
 extern int psubstitute(objinstptr);
 extern Boolean has_param(genericptr);
