@@ -99,7 +99,7 @@
 char	 _STR2[250];  /* Specifically for text returned from the popup prompt */
 char	 _STR[150];   /* Generic multipurpose string */
 short	 popups;      /* total number of popup widgets on the screen */
-Boolean	 pressmode;   /* Whether we are in a press & hold state */
+int	 pressmode;   /* Whether we are in a press & hold state */
 Display  *dpy = NULL;        /* Works well to make this globally accessible */
 Colormap cmap;
 Pixmap   STIPPLE[STIPPLES];  /* Polygon fill-style stipple patterns */
@@ -1180,7 +1180,7 @@ void pre_initialize()
 
    popups = 0;        /* no popup windows yet */
    beeper = 1;        /* Ring bell on certain warnings or errors */
-   pressmode = FALSE; /* not in a button press & hold mode yet */
+   pressmode = 0;	/* not in a button press & hold mode yet */
    initsplines();	/* create lookup table of spline parameters */
 }
 
