@@ -1264,15 +1264,14 @@ enum {
    XCF_Exit /* 88 */,		XCF_Netlist /* 89 */,
    XCF_Swap /* 90 */,		XCF_Pin_Label /* 91 */,
    XCF_Pin_Global /* 92 */,	XCF_Info_Label /* 93 */,
-   XCF_Graphic	/* 94 */,	XCF_Rescale /* 95 */,
-   XCF_SelectBox /* 96 */,	XCF_Connectivity /* 97 */,
-   XCF_Continue_Copy /* 98 */,	XCF_Continue_Element /* 99 */,
-   XCF_Finish_Copy /* 100 */,	XCF_Finish_Element /* 101 */,
-   XCF_Finish /* 102 */,	XCF_Cancel_Last /* 103 */,
-   XCF_Sim /* 104 */,		XCF_SPICE /* 105 */,
-   XCF_PCB /* 106 */,		XCF_SPICEflat /* 107 */,
-   XCF_Color /* 108 */,		XCF_Text_Delete_Param /* 109 */,
-   XCF_Scale /* 110 */,
+   XCF_Graphic	/* 94 */,	XCF_SelectBox /* 95 */,
+   XCF_Connectivity /* 96 */,	XCF_Continue_Element /* 97 */,
+   XCF_Finish_Element /* 98 */, XCF_Continue_Copy /* 99 */,
+   XCF_Finish_Copy /* 100 */,	XCF_Finish /* 101 */,
+   XCF_Cancel_Last /* 102 */,	XCF_Sim /* 103 */,
+   XCF_SPICE /* 104 */,		XCF_PCB /* 105 */,
+   XCF_SPICEflat /* 106 */,	XCF_Rescale /* 107 */,		
+   XCF_Text_Delete_Param /* 108 */,
    NUM_FUNCTIONS
 };
 
