@@ -104,6 +104,218 @@ void toggleencodings(xcWidget button) {
       toggleexcl(button, FontEncodings, XtNumber(FontEncodings));
 }
 
+/*--------------------------------------------------------------*/
+/* Toggle a bit in the justification field of a label		*/
+/*--------------------------------------------------------------*/
+
+void dojustifybit(xcWidget w, labelptr settext, short bitfield)
+{
+   if (settext != NULL) {
+      int oldjust = (int)settext->justify;
+
+      undrawtext(settext);
+      settext->justify ^= bitfield;
+      redrawtext(settext);
+      pwriteback(areawin->topinstance);
+
+      register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldjust);
+   }
+   else
+      areawin->justify ^= bitfield;
+
+   if (w != NULL) {
+      Boolean boolval;
+      if (settext)
+	 boolval = (settext->justify & bitfield) ? 0 : 1;
+      else
+	 boolval = (areawin->justify & bitfield) ? 0 : 1;
+      toggle(w, (pointertype)(-1), &boolval);
+   }
+}
+
+/*--------------------------------------------------------------*/
+/* Toggle a pin-related bit in the justification field of a	*/
+/* label.  This differs from dojustifybit() in that the label	*/
+/* must be a pin, and this function cannot change the default	*/
+/* behavior set by areawin->justify.				*/
+/*--------------------------------------------------------------*/
+
+void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
+{
+   if ((settext != NULL) && settext->pin) {
+      int oldjust = (int)settext->justify;
+
+      undrawtext(settext);
+      settext->justify ^= bitfield;
+      redrawtext(settext);
+      pwriteback(areawin->topinstance);
+
+      register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldjust);
+
+      if (w != NULL) {
+	 Boolean boolval = (settext->justify & bitfield) ? 0 : 1;
+	 toggle(w, (pointertype)(-1), &boolval);
+      }
+   }
+}
+
+/*----------------------------------------------------------------*/
+/* Set the justification for the label passed as 3rd parameter	  */
+/*----------------------------------------------------------------*/
+
+void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
+{
+   short newjust, oldjust;
+
+   if (settext != NULL) {
+
+      if (mode == 1)
+         newjust = (settext->justify & (NONJUSTFIELD | TBJUSTFIELD))
+			| value;
+      else
+         newjust = (settext->justify & (NONJUSTFIELD | RLJUSTFIELD))
+			| value;
+
+      if (settext->justify != newjust) {
+	  oldjust = (int)settext->justify;
+          undrawtext(settext);
+          settext->justify = newjust;
+          redrawtext(settext);
+          pwriteback(areawin->topinstance);
+
+          register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldjust);
+      }
+   }
+   else {
+      if (mode == 1)
+         newjust = (areawin->justify & (NONJUSTFIELD | TBJUSTFIELD))
+			| value;
+      else
+         newjust = (areawin->justify & (NONJUSTFIELD | RLJUSTFIELD))
+			| value;
+      areawin->justify = newjust;
+   }
+   if (w != NULL) togglejustifs(w);
+}
+
+/*----------------------------------------------------------------*/
+/* Set vertical justification (top, middle, bottom) on all	  */
+/* selected labels						  */
+/*----------------------------------------------------------------*/
+
+void setvjust(xcWidget w, pointertype value, caddr_t nulldata)
+{
+   short *fselect;
+   labelptr settext;
+   short labelcount = 0;
+
+   if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
+      settext = *((labelptr *)EDITPART);
+      setjust(w, value, settext, 2);
+   }
+   else {
+      for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
+         if (SELECTTYPE(fselect) == LABEL) {
+            labelcount++;
+            settext = SELTOLABEL(fselect);
+            setjust(NULL, value, settext, 2);
+         }
+      }
+      if (labelcount == 0) setjust(w, value, NULL, 2);
+      else unselect_all();
+   }
+}
+
+/*----------------------------------------------------------------*/
+/* Set horizontal justification (left, center, right) on all	  */
+/* selected labels						  */
+/*----------------------------------------------------------------*/
+
+void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
+{
+   short *fselect;
+   labelptr settext;
+   short labelcount = 0;
+
+   if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
+      settext = *((labelptr *)EDITPART);
+      setjust(w, value, settext, 1);
+   }
+   else {
+      for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
+         if (SELECTTYPE(fselect) == LABEL) {
+            labelcount++;
+            settext = SELTOLABEL(fselect);
+            setjust(NULL, value, settext, 1);
+         }
+      }
+      if (labelcount == 0) setjust(w, value, NULL, 1);
+      else unselect_all();
+   }
+}
+
+/*--------------------------------------------------------------*/
+/* Set a justify field bit on all selected labels		*/ 
+/* (flip invariance, latex mode, etc.)				*/
+/*--------------------------------------------------------------*/
+
+void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+{
+   short *fselect;
+   labelptr settext;
+   short labelcount = 0;
+
+   if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
+      settext = *((labelptr *)EDITPART);
+      dojustifybit(w, settext, (short)value);
+   }
+   else {
+      for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
+         if (SELECTTYPE(fselect) == LABEL) {
+            labelcount++;
+            settext = SELTOLABEL(fselect);
+            dojustifybit(NULL, settext, (short)value);
+         }
+      }
+      if (labelcount == 0) dojustifybit(w, NULL, (short)value);
+      else unselect_all();
+   }
+}
+
+/*--------------------------------------------------------------*/
+/* Set pin-related bit field of "justify" on all selected pins	*/ 
+/* (e.g., pin visibility)					*/
+/*--------------------------------------------------------------*/
+
+void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+{
+   short *fselect;
+   labelptr settext;
+
+   if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
+      settext = *((labelptr *)EDITPART);
+      if (settext->pin)
+	 dopinjustbit(w, settext, (short)value);
+   }
+   else {
+      for (fselect = areawin->selectlist; fselect < areawin->selectlist +
+            areawin->selects; fselect++) {
+         if (SELECTTYPE(fselect) == LABEL) {
+            settext = SELTOLABEL(fselect);
+	    if (settext->pin)
+               dopinjustbit(NULL, settext, (short)value);
+         }
+      }
+      unselect_all();
+   }
+}
+
 /*--------------------------------------------------------------*/
 /* Enable or Disable the toolbar				*/
 /*--------------------------------------------------------------*/
